@@ -5,8 +5,14 @@
 
 seqLLCP <- function(seq1,seq2) {
 
-	if (!inherits(seq1, "stslist") | !inherits(seq2, "stslist")) 
-		stop("sequences must be sequence objects")
+	if (!inherits(seq1,"stslist") | !inherits(seq2,"stslist")) {
+		stop(" [!] sequences must be sequence objects")
+	}
+	a1 <- alphabet(seq1)
+	a2 <- alphabet(seq2)
+	if(length(a1)!=length(a2) || any(a1!=a2)){
+		stop(" [!] The alphabet of both sequences have to be same.")
+	}
 
 	l1 <- seqlength(seq1)
 	l2 <- seqlength(seq2)
